==> puppet-module-barbican_15.4.0.orig.tar.xz: puppet-module-barbican-15.4.0/spec/classes/barbican_db_postgresql_spec.rb <==
#
# Copyright (C) 2016 Red Hat Inc. <licensing@redhat.com>
#
# Author: Ade Lee <alee@redhat.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
#
# Unit tests for barbican::db::postgresql class
#
require 'spec_helper'

describe 'barbican::db::postgresql' do

  shared_examples_for 'barbican::db::postgresql' do
    let :req_params do
      { :password => 'pw' }
    end

    let :pre_condition do
      'include postgresql::server'
    end

    context 'with only required parameters' do
      let :params do
        req_params
      end

      it { is_expected.to contain_postgresql__server__db('barbican').with(
        :user     => 'barbican',
        :password => 'md5699e09b3c7579f59869b882716fd7299'
      )}
    end

  end

  on_supported_os({
    :supported_os   => OSDefaults.get_supported_os
  }).each do |os,facts|
    context "on #{os}" do
      let (:facts) do
        facts.merge(OSDefaults.get_facts({
          :os_workers => 8,
          :concat_basedir => '/var/lib/puppet/concat'
        }))
      end

      it_configures 'barbican::db::postgresql'
    end
  end

end

==> puppet-module-barbican_17.4.0.orig.tar.xz: puppet-module-barbican-17.4.0/spec/classes/barbican_db_postgresql_spec.rb <==
#
# Copyright (C) 2016 Red Hat Inc. <licensing@redhat.com>
#
# Author: Ade Lee <alee@redhat.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
#
# Unit tests for barbican::db::postgresql class
#
require 'spec_helper'

describe 'barbican::db::postgresql' do

  shared_examples_for 'barbican::db::postgresql' do
    let :req_params do
      { :password => 'barbicanpass' }
    end

    let :pre_condition do
      'include postgresql::server'
    end

    context 'with only required parameters' do
      let :params do
        req_params
      end

      it { is_expected.to contain_openstacklib__db__postgresql('barbican').with(
        :user       => 'barbican',
        :password   => 'barbicanpass',
        :dbname     => 'barbican',
        :encoding   => nil,
        :privileges => 'ALL',
      )}
    end

  end

  on_supported_os({
    :supported_os   => OSDefaults.get_supported_os
  }).each do |os,facts|
    context "on #{os}" do
      let (:facts) do
        facts.merge(OSDefaults.get_facts({
          :os_workers => 8,
          :concat_basedir => '/var/lib/puppet/concat'
        }))
      end

      it_configures 'barbican::db::postgresql'
    end
  end

end
